%define major		65
%define libname 	%mklibname icu %{major}
%define develname 	%mklibname icu -d

%define dataname	%{name}%{major}-data

%define tarballver	%(echo %version|sed -e 's|\\.|_|g')
%define dashver		%(echo %version|sed -e 's|\\.|-|g')

# re-enable when upgrading this package to a new version
%define with_tests 0

Summary:	International Components for Unicode
Name:		icu
Version:	65.1
Release:	%mkrel 2
License:	Unicode
Group:		System/Libraries
URL:		http://site.icu-project.org/
Source0:	https://github.com/unicode-org/icu/releases/download/release-%{dashver}/icu4c-%{tarballver}-src.tgz
Patch0:		icu-50.1-disable-renaming.patch
Patch1:		icu-65-warnings.patch
BuildRequires:	doxygen
Requires:	%{libname} = %{version}

%description
The International Components for Unicode (ICU) libraries provide robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and they provide support
for supplementary Unicode characters (needed for GB 18030 repertoire support).

As computing environments become more heterogeneous, software portability
becomes more important. ICU lets you produce the same results across all the
various platforms you support, without sacrificing performance. It offers
great flexibility to extend and customize the supplied services, which
include:

  * Text: Unicode text handling, full character properties and character set
    conversions (500+ codepages)
  * Analysis: Unicode regular expressions; full Unicode sets; character, word
    and line boundaries
  * Comparison: Language sensitive collation and searching
  * Transformations: normalization, upper/lowercase, script transliterations
    (50+ pairs)
  * Locales: Comprehensive locale data (230+) and resource bundle architecture
  * Complex Text Layout: Arabic, Hebrew, Indic and Thai
  * Time: Multi-calendar and time zone
  * Formatting and Parsing: dates, times, numbers, currencies, messages and
    rule based

%package -n	%{dataname}
Summary:	Shared data for the International Components for Unicode
Group:		System/Libraries
BuildArch:	noarch

%description -n	%{dataname}
Shared data for the International Components for Unicode.

%package	doc
Summary:	Documentation for the International Components for Unicode
Group:		System/Libraries
Requires:	%{name}
BuildArch:	noarch

%description	doc
Documentation for the International Components for Unicode.

%package -n	%{libname}
Summary:	Libraries for the International Components for Unicode
Group:		System/Libraries
Requires:	%{dataname} = %{version}-%{release}


%description -n	%{libname}
Libraries for the International Components for Unicode.

%package -n	%{develname}
Summary:	Development files for the International Components for Unicode
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}%{major}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Development files and headers for the International Components for Unicode.

%prep
%setup -q -n %{name}
%apply_patches

%build
pushd source
%configure2_5x \
	--with-library-bits=64else32 \
	--with-data-packaging=archive \
	--disable-renaming \
	--disable-samples
mkdir -p data/out/tmp
# fix test failures
sed -i.testdata -r -e 's#/genrb#/genrb $(ICU_DATA_OPT)#' test/testdata/rules.mk
%__make
%__make doc
popd

%if %{with_tests}
%check
pushd source
export LC_ALL=C LANG=en
make check
popd
%endif

%install
%make_install -C source
%multiarch_binaries %{buildroot}%{_bindir}/icu-config

%files
%{_bindir}/*
%exclude %{_bindir}/icu-config
%exclude %{multiarch_bindir}
%{_sbindir}/*

%files -n %{dataname}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{version}
%{_datadir}/%{name}/%{version}/icudt%{major}l.dat

%files doc
%doc readme.html source/doc/html/*
%{_mandir}/man1/*
%{_mandir}/man8/*

%files -n %{libname}
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%{_bindir}/icu-config
%{multiarch_bindir}/icu-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/unicode
%{_includedir}/unicode/*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%{_libdir}/%{name}/%{version}/Makefile.inc
%{_libdir}/%{name}/%{version}/pkgdata.inc
%{_libdir}/%{name}/Makefile.inc
%{_libdir}/%{name}/current
%{_libdir}/%{name}/pkgdata.inc
%{_datadir}/%{name}/%{version}/config
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/LICENSE
%{_datadir}/%{name}/%{version}/mkinstalldirs


%changelog
* Sat Sep 10 2021 tex - 65.1-2pclos2021
- adjust pkg to ease upgrading

* Sat Oct 05 2019 tex - 65.1-1pclos2019
- new version 65.1 - new lib major 65
